==> dartgl-0.0.13.tar.gz: lib/dartgl_sdl.dart <==
library dartgl_sdl;
import 'dart-ext:dartgl_sdl';

int SDL_INIT_TIMER = 0x00000001;
int SDL_INIT_AUDIO =  0x00000010;
int SDL_INIT_VIDEO = 0x00000020;  /**< SDL_INIT_VIDEO implies SDL_INIT_EVENTS */
int SDL_INIT_JOYSTICK = 0x00000200;  /**< SDL_INIT_JOYSTICK implies SDL_INIT_EVENTS */
int SDL_INIT_HAPTIC = 0x00001000;
int SDL_INIT_GAMECONTROLLER = 0x00002000;  /**< SDL_INIT_GAMECONTROLLER implies SDL_INIT_JOYSTICK */
int SDL_INIT_EVENTS = 0x00004000;
int SDL_INIT_NOPARACHUTE = 0x00100000;  /**< Don't catch fatal signals */
int SDL_INIT_EVERYTHING  = SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |  
                SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER;

int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

int SDL_GL_RED_SIZE = 0x00000000; 
int SDL_GL_GREEN_SIZE = 0x00000001;
int SDL_GL_BLUE_SIZE = 0x00000002;
int SDL_GL_ALPHA_SIZE = 0x00000003;
int SDL_GL_BUFFER_SIZE = 0x00000004;
int SDL_GL_DOUBLEBUFFER = 0x00000005;
int SDL_GL_DEPTH_SIZE = 0x00000006;
int SDL_GL_STENCIL_SIZE = 0x00000007;
int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
int SDL_GL_STEREO = 0x0000000C;
int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
int SDL_GL_RETAINED_BACKING = 0x00000010;
int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
int SDL_GL_CONTEXT_EGL = 0x00000013;
int SDL_GL_CONTEXT_FLAGS = 0x00000014;
int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

int SDL_FIRSTEVENT     = 0;     /**< Unused (do not remove) */

/* Application events */
int SDL_QUIT           = 0x100; /**< User-requested quit */

/* These application events have special meaning on iOS, see README-ios.txt for details */
int SDL_APP_TERMINATING;        /**< The application is being terminated by the OS
                                 Called on iOS in applicationWillTerminate()
                                 Called on Android in onDestroy()
                            */
int SDL_APP_LOWMEMORY;          /**< The application is low on memory, free memory if possible.
                                 Called on iOS in applicationDidReceiveMemoryWarning()
                                 Called on Android in onLowMemory()
                            */
int SDL_APP_WILLENTERBACKGROUND; /**< The application is about to enter the background
                                 Called on iOS in applicationWillResignActive()
                                 Called on Android in onPause()
                            */
int SDL_APP_DIDENTERBACKGROUND; /**< The application did enter the background and may not get CPU for some time
                                 Called on iOS in applicationDidEnterBackground()
                                 Called on Android in onPause()
                            */
int SDL_APP_WILLENTERFOREGROUND; /**< The application is about to enter the foreground
                                 Called on iOS in applicationWillEnterForeground()
                                 Called on Android in onResume()
                            */
int SDL_APP_DIDENTERFOREGROUND; /**< The application is now interactive
                                 Called on iOS in applicationDidBecomeActive()
                                 Called on Android in onResume()
                            */

/* Window events */
int SDL_WINDOWEVENT = 0x200; /**< Window state change */
int SDL_SYSWMEVENT = 0x201;             /**< System specific event */

/* Keyboard events */
int SDL_KEYDOWN = 0x300; /**< Key pressed */
int SDL_KEYUP = 0x301;                  /**< Key released */
int SDL_TEXTEDITING = 0x302;            /**< Keyboard text editing (composition) */
int SDL_TEXTINPUT = 0x303;              /**< Keyboard text input */

/* Mouse events */
int SDL_MOUSEMOTION = 0x400; /**< Mouse moved */
int SDL_MOUSEBUTTONDOWN = 0x401;        /**< Mouse button pressed */
int SDL_MOUSEBUTTONUP = 0x402;          /**< Mouse button released */
int SDL_MOUSEWHEEL  = 0x403;             /**< Mouse wheel motion */

/* Joystick events */
int SDL_JOYAXISMOTION  = 0x600; /**< Joystick axis motion */
int SDL_JOYBALLMOTION;          /**< Joystick trackball motion */
int SDL_JOYHATMOTION;           /**< Joystick hat position change */
int SDL_JOYBUTTONDOWN;          /**< Joystick button pressed */
int SDL_JOYBUTTONUP;            /**< Joystick button released */
int SDL_JOYDEVICEADDED;         /**< A new joystick has been inserted into the system */
int SDL_JOYDEVICEREMOVED;       /**< An opened joystick has been removed */

/* Game controller events */
int SDL_CONTROLLERAXISMOTION  = 0x650; /**< Game controller axis motion */
int SDL_CONTROLLERBUTTONDOWN;          /**< Game controller button pressed */
int SDL_CONTROLLERBUTTONUP;            /**< Game controller button released */
int SDL_CONTROLLERDEVICEADDED;         /**< A new Game controller has been inserted into the system */
int SDL_CONTROLLERDEVICEREMOVED;       /**< An opened Game controller has been removed */
int SDL_CONTROLLERDEVICEREMAPPED;      /**< The controller mapping was updated */

/* Touch events */
int SDL_FINGERDOWN      = 0x700;
int SDL_FINGERUP;
int SDL_FINGERMOTION;

/* Gesture events */
int SDL_DOLLARGESTURE   = 0x800;
int SDL_DOLLARRECORD;
int SDL_MULTIGESTURE;

/* Clipboard events */
int SDL_CLIPBOARDUPDATE = 0x900; /**< The clipboard changed */

/* Drag and drop events */
int SDL_DROPFILE        = 0x1000; /**< The system requests a file open */

/** Events ::SDL_USEREVENT through ::SDL_LASTEVENT are for your use,
 *  and should be allocated with SDL_RegisterEvenint SDL_
 */
int SDL_USEREVENT    = 0x8000;

/**
 *  This last event is only for bounding internal arrays
 */
int SDL_LASTEVENT    = 0xFFFF;

int SDL_Init(int flags) native "SDL_Init";
int SDL_InitSubSystem(int flags) native "SDL_InitSubSystem";
void SDL_QuitSubSystem(int flags) native "SDL_QuitSubSystem";
int SDL_WasInit(int flags) native "SDL_WasInit";
void SDL_Quit() native "SDL_Quit";

Pointer SDL_CreateWindow(String title, int x, int y, int w, int h, int flags) native "SDL_CreateWindow";
void SDL_ShowWindow(Pointer window) native "SDL_ShowWindow";
void SDL_DestroyWindow(Pointer window) native "SDL_DestroyWindow";
void SDL_HideWindow(Pointer window) native "SDL_HideWindow";
void SDL_RaiseWindow(Pointer window) native "SDL_RaiseWindow";
void SDL_MaximizeWindow(Pointer window) native "SDL_MaximizeWindow";
void SDL_MinimizeWindow(Pointer window) native "SDL_MinimizeWindow";
void SDL_RestoreWindow(Pointer window) native "SDL_RestoreWindow";
int SDL_SetWindowFullscreen(Pointer window, int flags) native "SDL_SetWindowFullscreen";

int SDL_PollEvent(Event e) native "SDL_PollEvent";

Pointer SDL_GL_CreateContext(Pointer window) native "SDL_GL_CreateContext";
void SDL_GL_DeleteContext(Pointer context) native "SDL_GL_DeleteContext";
void SDL_GL_MakeCurrent(Pointer window, Pointer context) native "SDL_GL_MakeCurrent";
Pointer SDL_GL_GetCurrentContext() native "SDL_GL_GetCurrentContext";
Pointer SDL_GL_GetCurrentWindow() native "SDL_GL_GetCurrentWindow";
void SDL_GL_SwapWindow(Pointer window) native "SDL_GL_SwapWindow";
void SDL_GL_SetSwapInterval(int value) native "SDL_GL_SetSwapInterval";
int SDL_GL_GetSwapInterval() native "SDL_GL_GetSwapInterval";
void SDL_GL_SetAttribute(int attr, int value) native "SDL_GL_SetAttribute";

Pointer SDL_Test() native "SDL_Test";

class Event {
  int type;
  
  CommonEvent common;         /**< Common event data */
  WindowEvent window;         /**< Window event data */
  KeyboardEvent key;          /**< Keyboard event data */
  //TextEditingEvent edit;      /**< Text editing event data */
  //TextInputEvent text;        /**< Text input event data */
  MouseMotionEvent motion;    /**< Mouse motion event data */
  MouseButtonEvent button;    /**< Mouse button event data */
  MouseWheelEvent wheel;      /**< Mouse wheel event data */
  //..
}

class CommonEvent
{
  int type;
  int timestamp;
}

class WindowEvent
{
  int type;        /**< ::SDL_WINDOWEVENT */
  int timestamp;
  int windowID;    /**< The associated window */
  int event;        /**< ::SDL_WindowEventID */
  int padding1;
  int padding2;
  int padding3;
  int data1;       /**< event dependent data */
  int data2;       /**< event dependent data */
}

class KeyboardEvent
{
  int type;        /**< ::SDL_KEYDOWN or ::SDL_KEYUP */
  int timestamp;
  int windowID;    /**< The window with keyboard focus, if any */
  int state;        /**< ::SDL_PRESSED or ::SDL_RELEASED */
  int repeat;       /**< Non-zero if this is a key repeat */
  int padding2;
  int padding3;
  //SDL_Keysym keysym;  /**< The key that was pressed or released */
}

class MouseMotionEvent {
  int type;        /**< ::SDL_MOUSEMOTION */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int state;       /**< The current button state */
  int x;           /**< X coordinate, relative to window */
  int y;           /**< Y coordinate, relative to window */
  int xrel;        /**< The relative motion in the X direction */
  int yrel;        /**< The relative motion in the Y direction */
}

class MouseButtonEvent
{
  int type;        /**< ::SDL_MOUSEBUTTONDOWN or ::SDL_MOUSEBUTTONUP */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int button;       /**< The mouse button index */
  int state;        /**< ::SDL_PRESSED or ::SDL_RELEASED */
  int padding1;
  int padding2;
  int x;           /**< X coordinate, relative to window */
  int y;           /**< Y coordinate, relative to window */
}

class MouseWheelEvent
{
  int type;        /**< ::SDL_MOUSEWHEEL */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int x;           /**< The amount scrolled horizontally */
  int y;           /**< The amount scrolled vertically */
}


class Pointer {
  int pointer;
  
  Pointer(){}
  Pointer.main(){}
}

==> dartgl-0.0.18.tar.gz: lib/dartgl_sdl.dart <==
library dartgl_sdl;
import 'dart-ext:dartgl_sdl';

int SDL_INIT_TIMER = 0x00000001;
int SDL_INIT_AUDIO =  0x00000010;
int SDL_INIT_VIDEO = 0x00000020;  /**< SDL_INIT_VIDEO implies SDL_INIT_EVENTS */
int SDL_INIT_JOYSTICK = 0x00000200;  /**< SDL_INIT_JOYSTICK implies SDL_INIT_EVENTS */
int SDL_INIT_HAPTIC = 0x00001000;
int SDL_INIT_GAMECONTROLLER = 0x00002000;  /**< SDL_INIT_GAMECONTROLLER implies SDL_INIT_JOYSTICK */
int SDL_INIT_EVENTS = 0x00004000;
int SDL_INIT_NOPARACHUTE = 0x00100000;  /**< Don't catch fatal signals */
int SDL_INIT_EVERYTHING  = SDL_INIT_TIMER | SDL_INIT_AUDIO | SDL_INIT_VIDEO | SDL_INIT_EVENTS |  
                SDL_INIT_JOYSTICK | SDL_INIT_HAPTIC | SDL_INIT_GAMECONTROLLER;

int SDL_WINDOW_FULLSCREEN = 0x00000001;         /**< fullscreen window */
int SDL_WINDOW_OPENGL = 0x00000002;             /**< window usable with OpenGL context */
int SDL_WINDOW_SHOWN = 0x00000004;              /**< window is visible */
int SDL_WINDOW_HIDDEN = 0x00000008;             /**< window is not visible */
int SDL_WINDOW_BORDERLESS = 0x00000010;         /**< no window decoration */
int SDL_WINDOW_RESIZABLE = 0x00000020;          /**< window can be resized */
int SDL_WINDOW_MINIMIZED = 0x00000040;          /**< window is minimized */
int SDL_WINDOW_MAXIMIZED = 0x00000080;          /**< window is maximized */
int SDL_WINDOW_INPUT_GRABBED = 0x00000100;      /**< window has grabbed input focus */
int SDL_WINDOW_INPUT_FOCUS = 0x00000200;        /**< window has input focus */
int SDL_WINDOW_MOUSE_FOCUS = 0x00000400;        /**< window has mouse focus */
int SDL_WINDOW_FULLSCREEN_DESKTOP = ( SDL_WINDOW_FULLSCREEN | 0x00001000 );
int SDL_WINDOW_FOREIGN = 0x00000800;            /**< window not created by SDL */

int SDL_GL_RED_SIZE = 0x00000000; 
int SDL_GL_GREEN_SIZE = 0x00000001;
int SDL_GL_BLUE_SIZE = 0x00000002;
int SDL_GL_ALPHA_SIZE = 0x00000003;
int SDL_GL_BUFFER_SIZE = 0x00000004;
int SDL_GL_DOUBLEBUFFER = 0x00000005;
int SDL_GL_DEPTH_SIZE = 0x00000006;
int SDL_GL_STENCIL_SIZE = 0x00000007;
int SDL_GL_ACCUM_RED_SIZE = 0x00000008;
int SDL_GL_ACCUM_GREEN_SIZE = 0x00000009;
int SDL_GL_ACCUM_BLUE_SIZE = 0x0000000A;
int SDL_GL_ACCUM_ALPHA_SIZE = 0x0000000B;
int SDL_GL_STEREO = 0x0000000C;
int SDL_GL_MULTISAMPLEBUFFERS = 0x0000000D;
int SDL_GL_MULTISAMPLESAMPLES = 0x0000000E;
int SDL_GL_ACCELERATED_VISUAL = 0x0000000F;
int SDL_GL_RETAINED_BACKING = 0x00000010;
int SDL_GL_CONTEXT_MAJOR_VERSION = 0x00000011;
int SDL_GL_CONTEXT_MINOR_VERSION = 0x00000012;
int SDL_GL_CONTEXT_EGL = 0x00000013;
int SDL_GL_CONTEXT_FLAGS = 0x00000014;
int SDL_GL_CONTEXT_PROFILE_MASK = 0x00000015;
int SDL_GL_SHARE_WITH_CURRENT_CONTEXT = 0x00000016;

int SDL_FIRSTEVENT     = 0;     /**< Unused (do not remove) */

/* Application events */
int SDL_QUIT           = 0x100; /**< User-requested quit */

/* These application events have special meaning on iOS, see README-ios.txt for details */
int SDL_APP_TERMINATING;        /**< The application is being terminated by the OS
                                 Called on iOS in applicationWillTerminate()
                                 Called on Android in onDestroy()
                            */
int SDL_APP_LOWMEMORY;          /**< The application is low on memory, free memory if possible.
                                 Called on iOS in applicationDidReceiveMemoryWarning()
                                 Called on Android in onLowMemory()
                            */
int SDL_APP_WILLENTERBACKGROUND; /**< The application is about to enter the background
                                 Called on iOS in applicationWillResignActive()
                                 Called on Android in onPause()
                            */
int SDL_APP_DIDENTERBACKGROUND; /**< The application did enter the background and may not get CPU for some time
                                 Called on iOS in applicationDidEnterBackground()
                                 Called on Android in onPause()
                            */
int SDL_APP_WILLENTERFOREGROUND; /**< The application is about to enter the foreground
                                 Called on iOS in applicationWillEnterForeground()
                                 Called on Android in onResume()
                            */
int SDL_APP_DIDENTERFOREGROUND; /**< The application is now interactive
                                 Called on iOS in applicationDidBecomeActive()
                                 Called on Android in onResume()
                            */

/* Window events */
int SDL_WINDOWEVENT = 0x200; /**< Window state change */
int SDL_SYSWMEVENT = 0x201;             /**< System specific event */

/* Keyboard events */
int SDL_KEYDOWN = 0x300; /**< Key pressed */
int SDL_KEYUP = 0x301;                  /**< Key released */
int SDL_TEXTEDITING = 0x302;            /**< Keyboard text editing (composition) */
int SDL_TEXTINPUT = 0x303;              /**< Keyboard text input */

/* Mouse events */
int SDL_MOUSEMOTION = 0x400; /**< Mouse moved */
int SDL_MOUSEBUTTONDOWN = 0x401;        /**< Mouse button pressed */
int SDL_MOUSEBUTTONUP = 0x402;          /**< Mouse button released */
int SDL_MOUSEWHEEL  = 0x403;             /**< Mouse wheel motion */

/* Joystick events */
int SDL_JOYAXISMOTION  = 0x600; /**< Joystick axis motion */
int SDL_JOYBALLMOTION;          /**< Joystick trackball motion */
int SDL_JOYHATMOTION;           /**< Joystick hat position change */
int SDL_JOYBUTTONDOWN;          /**< Joystick button pressed */
int SDL_JOYBUTTONUP;            /**< Joystick button released */
int SDL_JOYDEVICEADDED;         /**< A new joystick has been inserted into the system */
int SDL_JOYDEVICEREMOVED;       /**< An opened joystick has been removed */

/* Game controller events */
int SDL_CONTROLLERAXISMOTION  = 0x650; /**< Game controller axis motion */
int SDL_CONTROLLERBUTTONDOWN;          /**< Game controller button pressed */
int SDL_CONTROLLERBUTTONUP;            /**< Game controller button released */
int SDL_CONTROLLERDEVICEADDED;         /**< A new Game controller has been inserted into the system */
int SDL_CONTROLLERDEVICEREMOVED;       /**< An opened Game controller has been removed */
int SDL_CONTROLLERDEVICEREMAPPED;      /**< The controller mapping was updated */

/* Touch events */
int SDL_FINGERDOWN      = 0x700;
int SDL_FINGERUP;
int SDL_FINGERMOTION;

/* Gesture events */
int SDL_DOLLARGESTURE   = 0x800;
int SDL_DOLLARRECORD;
int SDL_MULTIGESTURE;

/* Clipboard events */
int SDL_CLIPBOARDUPDATE = 0x900; /**< The clipboard changed */

/* Drag and drop events */
int SDL_DROPFILE        = 0x1000; /**< The system requests a file open */

/** Events ::SDL_USEREVENT through ::SDL_LASTEVENT are for your use,
 *  and should be allocated with SDL_RegisterEvenint SDL_
 */
int SDL_USEREVENT    = 0x8000;

/**
 *  This last event is only for bounding internal arrays
 */
int SDL_LASTEVENT    = 0xFFFF;

int SDL_WINDOWEVENT_NONE = 0;           /**< Never used */
int SDL_WINDOWEVENT_SHOWN = 1;          /**< Window has been shown */
int SDL_WINDOWEVENT_HIDDEN = 2;         /**< Window has been hidden */
int SDL_WINDOWEVENT_EXPOSED = 3;        /**< Window has been exposed and should be redrawn */
int SDL_WINDOWEVENT_MOVED = 4;          /**< Window has been moved to data1 = 0; data2 */
int SDL_WINDOWEVENT_RESIZED = 5;        /**< Window has been resized to data1xdata2 */
int SDL_WINDOWEVENT_SIZE_CHANGED = 6;   /**< The window size has changed = 0; either as a result of an API call or through the system or user changing the window size. */
int SDL_WINDOWEVENT_MINIMIZED = 7;      /**< Window has been minimized */
int SDL_WINDOWEVENT_MAXIMIZED = 8;      /**< Window has been maximized */
int SDL_WINDOWEVENT_RESTORED = 9;       /**< Window has been restored to normal size and position */
int SDL_WINDOWEVENT_ENTER = 10;          /**< Window has gained mouse focus */
int SDL_WINDOWEVENT_LEAVE = 11;          /**< Window has lost mouse focus */
int SDL_WINDOWEVENT_FOCUS_GAINED = 12;   /**< Window has gained keyboard focus */
int SDL_WINDOWEVENT_FOCUS_LOST = 13;     /**< Window has lost keyboard focus */
int SDL_WINDOWEVENT_CLOSE = 14;          /**< The window manager requests that the window be closed */

int SDL_Init(int flags) native "SDL_Init";
int SDL_InitSubSystem(int flags) native "SDL_InitSubSystem";
void SDL_QuitSubSystem(int flags) native "SDL_QuitSubSystem";
int SDL_WasInit(int flags) native "SDL_WasInit";
void SDL_Quit() native "SDL_Quit";

Pointer SDL_CreateWindow(String title, int x, int y, int w, int h, int flags) native "SDL_CreateWindow";
void SDL_ShowWindow(Pointer window) native "SDL_ShowWindow";
void SDL_DestroyWindow(Pointer window) native "SDL_DestroyWindow";
void SDL_HideWindow(Pointer window) native "SDL_HideWindow";
void SDL_RaiseWindow(Pointer window) native "SDL_RaiseWindow";
void SDL_MaximizeWindow(Pointer window) native "SDL_MaximizeWindow";
void SDL_MinimizeWindow(Pointer window) native "SDL_MinimizeWindow";
void SDL_RestoreWindow(Pointer window) native "SDL_RestoreWindow";
int SDL_SetWindowFullscreen(Pointer window, int flags) native "SDL_SetWindowFullscreen";

int SDL_PollEvent(SDL_Event e) native "SDL_PollEvent";

Pointer SDL_GL_CreateContext(Pointer window) native "SDL_GL_CreateContext";
void SDL_GL_DeleteContext(Pointer context) native "SDL_GL_DeleteContext";
void SDL_GL_MakeCurrent(Pointer window, Pointer context) native "SDL_GL_MakeCurrent";
Pointer SDL_GL_GetCurrentContext() native "SDL_GL_GetCurrentContext";
Pointer SDL_GL_GetCurrentWindow() native "SDL_GL_GetCurrentWindow";
void SDL_GL_SwapWindow(Pointer window) native "SDL_GL_SwapWindow";
void SDL_GL_SetSwapInterval(int value) native "SDL_GL_SetSwapInterval";
int SDL_GL_GetSwapInterval() native "SDL_GL_GetSwapInterval";
void SDL_GL_SetAttribute(int attr, int value) native "SDL_GL_SetAttribute";

Pointer SDL_Test() native "SDL_Test";

class SDL_Event {
  int type;
  
  SDL_CommonEvent common;         /**< Common event data */
  SDL_WindowEvent window;         /**< Window event data */
  SDL_KeyboardEvent key;          /**< Keyboard event data */
  //SDL_TextEditingEvent edit;      /**< Text editing event data */
  //SDL_TextInputEvent text;        /**< Text input event data */
  SDL_MouseMotionEvent motion;    /**< Mouse motion event data */
  SDL_MouseButtonEvent button;    /**< Mouse button event data */
  SDL_MouseWheelEvent wheel;      /**< Mouse wheel event data */
  //..
}

class SDL_CommonEvent
{
  int type;
  int timestamp;
}

class SDL_WindowEvent
{
  int type;        /**< ::SDL_WINDOWEVENT */
  int timestamp;
  int windowID;    /**< The associated window */
  int event;        /**< ::SDL_WindowEventID */
  int padding1;
  int padding2;
  int padding3;
  int data1;       /**< event dependent data */
  int data2;       /**< event dependent data */
}

class SDL_KeyboardEvent
{
  int type;        /**< ::SDL_KEYDOWN or ::SDL_KEYUP */
  int timestamp;
  int windowID;    /**< The window with keyboard focus, if any */
  int state;        /**< ::SDL_PRESSED or ::SDL_RELEASED */
  int repeat;       /**< Non-zero if this is a key repeat */
  int padding2;
  int padding3;
  SDL_Keysym keysym;  /**< The key that was pressed or released */
}

class SDL_MouseMotionEvent {
  int type;        /**< ::SDL_MOUSEMOTION */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int state;       /**< The current button state */
  int x;           /**< X coordinate, relative to window */
  int y;           /**< Y coordinate, relative to window */
  int xrel;        /**< The relative motion in the X direction */
  int yrel;        /**< The relative motion in the Y direction */
}

class SDL_MouseButtonEvent
{
  int type;        /**< ::SDL_MOUSEBUTTONDOWN or ::SDL_MOUSEBUTTONUP */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int button;       /**< The mouse button index */
  int state;        /**< ::SDL_PRESSED or ::SDL_RELEASED */
  int padding1;
  int padding2;
  int x;           /**< X coordinate, relative to window */
  int y;           /**< Y coordinate, relative to window */
}

class SDL_MouseWheelEvent
{
  int type;        /**< ::SDL_MOUSEWHEEL */
  int timestamp;
  int windowID;    /**< The window with mouse focus, if any */
  int which;       /**< The mouse instance id, or SDL_TOUCH_MOUSEID */
  int x;           /**< The amount scrolled horizontally */
  int y;           /**< The amount scrolled vertically */
}

class SDL_Keysym
{
    int scancode;      /**< SDL physical key code - see ::SDL_Scancode for details */
    int sym;            /**< SDL virtual key code - see ::SDL_Keycode for details */
    int mod;                 /**< current key modifiers */
    int unused;
}

class Pointer {
  int pointer;
  
  Pointer(){}
  Pointer.main(){}
}
